@@ -164,16 +164,26 @@ class LXDContainerConfig(object):
         # Determine if we require a nested container
         flavor = instance.flavor
         lxd_nested_allowed = flavor.extra_specs.get(
-            'lxd_nested_allowed', False)
+            'lxd:nested_allowed', False)
         if lxd_nested_allowed:
             config['security.nesting'] = 'True'
 
         # Determine if we require a privileged container
         lxd_privileged_allowed = flavor.extra_specs.get(
-            'lxd_privileged_allowed', False)
+            'lxd:privileged_allowed', False)
         if lxd_privileged_allowed:
             config['security.privileged'] = 'True'
 
+        lxd_isolated = flavor.extra_specs.get(
+            'lxd:isolated', False)
+        if lxd_isolated:
+            extensions = self.session.get_host_extensions()
+            if 'id_map' in extensions:
+                config['security.idmap.isolated'] = 'True'
+            else:
+                msg = _('Host does not support isolated instances')
+                raise exception.NovaException(msg)
+
         return config
 
     def configure_container_root(self, instance):
