@@ -27,8 +27,8 @@ from nova import i18n
 from nova import utils
 import os
 import platform
-from pylxd import api
-from pylxd import exceptions as lxd_exceptions
+from pylxd.deprecated import api
+from pylxd.deprecated import exceptions as lxd_exceptions
 import socket
 
 from oslo_config import cfg
@@ -71,11 +71,11 @@ class LXDHost(object):
             'hypervisor_version': '011',
             'cpu_info': jsonutils.dumps(local_cpu_info),
             'hypervisor_hostname': socket.gethostname(),
-            'supported_instances': jsonutils.dumps(
+            'supported_instances':
                 [(arch.I686, hv_type.LXD, vm_mode.EXE),
                     (arch.X86_64, hv_type.LXD, vm_mode.EXE),
                     (arch.I686, hv_type.LXC, vm_mode.EXE),
-                    (arch.X86_64, hv_type.LXC, vm_mode.EXE)]),
+                    (arch.X86_64, hv_type.LXC, vm_mode.EXE)],
             'numa_topology': None,
         }
 
@@ -180,12 +180,13 @@ class LXDHost(object):
         return '.'.join(str(v) for v in version)
 
     def get_host_cpu_stats(self):
+        cpuinfo = self._get_cpu_info()
         return {
             'kernel': int(psutil.cpu_times()[2]),
             'idle': int(psutil.cpu_times()[3]),
             'user': int(psutil.cpu_times()[0]),
             'iowait': int(psutil.cpu_times()[4]),
-            'frequency': self.host_cpu_info['hz_advertised']
+            'frequency': cpuinfo.get('cpu mhz', 0)
         }
 
     def init_host(self, host):
@@ -195,10 +196,6 @@ class LXDHost(object):
                 msg = _('Unable to connect to LXD daemon')
                 raise exception.HostNotFound(msg)
 
-            if CONF.lxd.default_profile not in self.lxd.profile_list():
-                profile = {'name': CONF.lxd.default_profile}
-                self.lxd.profile_create(profile)
-
             return True
         except lxd_exceptions.APIError as ex:
             msg = _('Unable to connect to LXD daemon: %s') % ex
