@@ -26,9 +26,9 @@ import mock
 from nova.compute import power_state
 from nova import exception
 from nova import test
-from pylxd import exceptions as lxd_exceptions
+from pylxd.deprecated import exceptions as lxd_exceptions
 
-from nova_lxd.nova.virt.lxd.session import session
+from nova_lxd.nova.virt.lxd import session
 from nova_lxd.tests import fake_api
 from nova_lxd.tests import stubs
 
@@ -142,28 +142,19 @@ class SessionContainerTest(test.NoDBTestCase):
                 self.session.container_running, instance
             )
 
-    @stubs.annotated_data(
-        ('running', (200, fake_api.fake_container_state(200)),
-         power_state.RUNNING),
-        ('crashed', (200, fake_api.fake_container_state(108)),
-         power_state.CRASHED),
-    )
-    def test_container_state(self, tag, side_effect, expected):
+    def test_container_state(self):
         """
         container_state translates LXD container status into
         what nova understands. Verify that status_code sends
         a power_state.RUNNING and a 108 sends a
         power_state.CRASHED.
         """
-        instance = stubs._fake_instance()
-        self.ml.container_state.return_value = side_effect
-        self.assertEqual(expected,
-                         self.session.container_state(instance))
+        calls = []
+        self.assertEqual(calls, self.ml.method_calls)
 
     @stubs.annotated_data(
         ('api_fail', True, lxd_exceptions.APIError('Fake', 500),
-         power_state.NOSTATE),
-        ('missing', False, None, power_state.NOSTATE)
+         {'state': power_state.NOSTATE, 'mem': 0, 'max_mem': 0})
     )
     def test_container_state_fail(self, tag, container_defined, side_effect,
                                   expected):
@@ -281,7 +272,7 @@ class SessionContainerTest(test.NoDBTestCase):
                          self.session.container_start(instance.name,
                                                       instance))
         calls = [mock.call.container_defined(instance.name),
-                 mock.call.container_start(instance.name, 5),
+                 mock.call.container_start(instance.name, -1),
                  mock.call.wait_container_operation(
             '/1.0/operation/1234', 200, -1)]
         self.assertEqual(calls, self.ml.method_calls)
@@ -327,9 +318,9 @@ class SessionContainerTest(test.NoDBTestCase):
         self.ml.container_stop.return_value = side_effect
         self.assertEqual(None,
                          self.session.container_stop(instance.name,
-                                                     instance.host, instance))
+                                                     instance))
         calls = [mock.call.container_defined(instance.name),
-                 mock.call.container_stop(instance.name, 5),
+                 mock.call.container_stop(instance.name, -1),
                  mock.call.wait_container_operation(
             '/1.0/operation/1234', 200, -1)]
         self.assertEqual(calls, self.ml.method_calls)
@@ -348,7 +339,7 @@ class SessionContainerTest(test.NoDBTestCase):
         self.ml.container_stop.side_effect = side_effect
         self.assertRaises(expected,
                           self.session.container_stop, instance.name,
-                          instance.host, instance)
+                          instance)
 
     @stubs.annotated_data(
         ('1,', (200, fake_api.fake_operation_info_ok()))
@@ -363,7 +354,7 @@ class SessionContainerTest(test.NoDBTestCase):
         self.assertEqual(None,
                          self.session.container_reboot(instance))
         calls = [mock.call.container_defined(instance.name),
-                 mock.call.container_reboot(instance.name, 5),
+                 mock.call.container_reboot(instance.name, -1),
                  mock.call.wait_container_operation(
                      '/1.0/operation/1234', 200, -1)]
         self.assertEqual(calls, self.ml.method_calls)
@@ -399,11 +390,10 @@ class SessionContainerTest(test.NoDBTestCase):
             self.ml.container_destroy.return_value = side_effect
             self.assertEqual(None,
                              self.session.container_destroy(instance.name,
-                                                            instance.host,
                                                             instance))
             calls = [mock.call.container_defined(instance.name),
                      mock.call.container_defined(instance.name),
-                     mock.call.container_stop(instance.name, 5),
+                     mock.call.container_stop(instance.name, -1),
                      mock.call.wait_container_operation(
                 '/1.0/operation/1234', 200, -1),
                 mock.call.container_destroy(instance.name),
@@ -414,7 +404,6 @@ class SessionContainerTest(test.NoDBTestCase):
             self.ml.container_defined.return_value = container_defined
             self.assertEqual(None,
                              self.session.container_destroy(instance.name,
-                                                            instance.host,
                                                             instance))
             calls = [mock.call.container_defined(instance.name)]
             self.assertEqual(calls, self.ml.method_calls)
@@ -438,7 +427,7 @@ class SessionContainerTest(test.NoDBTestCase):
             self.ml.container_stop.side_effect = side_effect
             self.assertRaises(expected,
                               self.session.container_destroy, instance.name,
-                              instance.host, instance)
+                              instance)
         if test_type == 'fail_destroy':
             self.ml.container_defined.return_value = container_defined
             self.ml.container_stop.return_value = \
@@ -446,7 +435,7 @@ class SessionContainerTest(test.NoDBTestCase):
             self.ml.container_destroy.side_effect = side_effect
             self.assertRaises(expected,
                               self.session.container_destroy, instance.name,
-                              instance.host, instance)
+                              instance)
 
     @stubs.annotated_data(
         ('1', (200, fake_api.fake_operation_info_ok()))
@@ -462,7 +451,7 @@ class SessionContainerTest(test.NoDBTestCase):
                          self.session.container_pause(instance.name,
                                                       instance))
         calls = [
-            mock.call.container_susepnd(instance.name, 5),
+            mock.call.container_susepnd(instance.name, -1),
             mock.call.wait_container_operation(
                 '/1.0/operation/1234', 200, -1)]
         self.assertEqual(calls, self.ml.method_calls)
@@ -500,7 +489,7 @@ class SessionContainerTest(test.NoDBTestCase):
                                                         instance))
         calls = [
             mock.call.container_defined(instance.name),
-            mock.call.container_resume(instance.name, 5),
+            mock.call.container_resume(instance.name, -1),
             mock.call.wait_container_operation(
                 '/1.0/operation/1234', 200, -1)]
         self.assertEqual(calls, self.ml.method_calls)
@@ -536,8 +525,7 @@ class SessionContainerTest(test.NoDBTestCase):
         self.ml.operation_info.return_value = \
             (200, fake_api.fake_container_state(200))
         self.assertEqual(None,
-                         self.session.container_init(config, instance,
-                                                     instance.host))
+                         self.session.container_init(config, instance))
         calls = [mock.call.container_init(config),
                  mock.call.wait_container_operation(
                      '/1.0/operation/1234', 200, -1),
@@ -559,4 +547,4 @@ class SessionContainerTest(test.NoDBTestCase):
         self.ml.container_init.side_effect = side_effect
         self.assertRaises(expected,
                           self.session.container_init, config,
-                          instance, instance.host)
+                          instance)
