@@ -18,7 +18,7 @@ import mock
 
 from nova import test
 
-from nova_lxd.nova.virt.lxd.session import session
+from nova_lxd.nova.virt.lxd import session
 from nova_lxd.tests import stubs
 
 
